@@ -46,6 +46,36 @@ type thread_model =
 | THREAD_MODEL_SERIALIZE_REQUESTS
 | THREAD_MODEL_PARALLEL
 
+type buf =
+  (char, Bigarray.int8_unsigned_elt, Bigarray.c_layout) Bigarray.Array1.t
+
+let buf_len = Bigarray.Array1.dim
+
+external _blit_from_string : string -> int -> buf -> int -> int -> unit
+  = "ocaml_nbdkit_blit_from" [@@noalloc]
+external _blit_from_bytes : bytes -> int -> buf -> int -> int -> unit
+  = "ocaml_nbdkit_blit_from" [@@noalloc]
+external _blit_to_bytes : buf -> int -> bytes -> int -> int -> unit
+  = "ocaml_nbdkit_blit_to_bytes" [@@noalloc]
+
+let blit_string_to_buf src src_pos buf buf_pos len =
+  if len < 0 || src_pos < 0 || src_pos > String.length src - len
+             || buf_pos < 0 || buf_pos > buf_len buf - len
+  then invalid_arg "NBDKit.blit_string_to_buf";
+  _blit_from_string src src_pos buf buf_pos len
+
+let blit_bytes_to_buf src src_pos buf buf_pos len =
+  if len < 0 || src_pos < 0 || src_pos > Bytes.length src - len
+             || buf_pos < 0 || buf_pos > buf_len buf - len
+  then invalid_arg "NBDKit.blit_bytes_to_buf";
+  _blit_from_bytes src src_pos buf buf_pos len
+
+let blit_buf_to_bytes buf buf_pos dst dst_pos len =
+  if len < 0 || buf_pos < 0 || buf_pos > buf_len buf - len
+             || dst_pos < 0 || dst_pos > Bytes.length dst - len
+  then invalid_arg "NBDKit.blit_buf_to_bytes";
+  _blit_to_bytes buf buf_pos dst dst_pos len
+
 type extent = {
   offset : int64;
   length : int64;
@@ -163,6 +193,8 @@ external parse_size : string -> int64 = "ocaml_nbdkit_parse_size"
 external parse_probability : string -> string -> float =
   "ocaml_nbdkit_parse_probability"
 external parse_bool : string -> bool = "ocaml_nbdkit_parse_bool"
+external parse_delay : string -> string -> int * int =
+  "ocaml_nbdkit_parse_delay"
 external read_password : string -> string = "ocaml_nbdkit_read_password"
 external stdio_safe : unit -> bool = "ocaml_nbdkit_stdio_safe"
 external realpath : string -> string = "ocaml_nbdkit_realpath"
@@ -181,3 +213,6 @@ external peer_uid : unit -> int64 = "ocaml_nbdkit_peer_uid"
 external peer_gid : unit -> int64 = "ocaml_nbdkit_peer_gid"
 external peer_security_context : unit -> string =
   "ocaml_nbdkit_peer_security_context"
+external peer_tls_dn : unit -> string = "ocaml_nbdkit_peer_tls_dn"
+external peer_tls_issuer_dn : unit -> string =
+  "ocaml_nbdkit_peer_tls_issuer_dn"
