@@ -130,8 +130,10 @@ extern const char *ipaddr;
 extern enum log_to log_to;
 extern unsigned mask_handshake;
 extern bool newstyle;
+extern bool no_mc;
 extern bool no_sr;
 extern const char *port;
+extern bool print_uri;
 extern bool read_only;
 extern const char *run;
 extern bool listen_stdin;
@@ -193,6 +195,9 @@ extern unsigned int get_socket_activation (void);
 /* usergroup.c */
 extern void change_user (void);
 
+/* uri.c */
+extern char *make_uri (void);
+
 /* connections.c */
 
 /* Flags for connection_send_function */
@@ -335,10 +340,10 @@ extern void free_debug_flags (void);
 extern void log_verror (const char *fs, va_list args);
 
 /* log-*.c */
-extern void log_stderr_verror (const char *fs, va_list args)
-  ATTRIBUTE_FORMAT_PRINTF (1, 0);
-extern void log_syslog_verror (const char *fs, va_list args)
-  ATTRIBUTE_FORMAT_PRINTF (1, 0);
+extern void log_stderr_verror (int orig_errno, const char *fs, va_list args)
+  ATTRIBUTE_FORMAT_PRINTF (2, 0);
+extern void log_syslog_verror (int orig_errno, const char *fs, va_list args)
+  ATTRIBUTE_FORMAT_PRINTF (2, 0);
 
 /* vfprintf.c */
 #if !HAVE_VFPRINTF_PERCENT_M
@@ -564,8 +569,11 @@ extern void threadlocal_set_name (const char *name)
 extern const char *threadlocal_get_name (void);
 extern void threadlocal_set_instance_num (size_t instance_num);
 extern size_t threadlocal_get_instance_num (void);
-extern void threadlocal_set_error (int err);
-extern int threadlocal_get_error (void);
+extern void threadlocal_set_errno (int err);
+extern int threadlocal_get_errno (void);
+extern void threadlocal_set_last_error (char *msg);
+extern void threadlocal_clear_last_error (void);
+extern const char *threadlocal_get_last_error (void);
 extern void *threadlocal_buffer (size_t size);
 extern void threadlocal_set_conn (struct connection *conn);
 extern struct connection *threadlocal_get_conn (void);
