@@ -47,7 +47,9 @@ enum {
   LOG_OPTION,
   LONG_OPTIONS_OPTION,
   MASK_HANDSHAKE_OPTION,
+  NO_MC_OPTION,
   NO_SR_OPTION,
+  PRINT_URI,
   RUN_OPTION,
   SELINUX_LABEL_OPTION,
   SHORT_OPTIONS_OPTION,
@@ -82,17 +84,24 @@ static const struct option long_options[] = {
   { "mask-handshake",   required_argument, NULL, MASK_HANDSHAKE_OPTION },
   { "new-style",        no_argument,       NULL, 'n' },
   { "newstyle",         no_argument,       NULL, 'n' },
+  { "no-mc",            no_argument,       NULL, NO_MC_OPTION },
+  { "no-meta-contexts", no_argument,       NULL, NO_MC_OPTION },
   { "no-sr",            no_argument,       NULL, NO_SR_OPTION },
+  { "no-structured-replies", no_argument,  NULL, NO_SR_OPTION },
   { "old-style",        no_argument,       NULL, 'o' },
   { "oldstyle",         no_argument,       NULL, 'o' },
   { "pid-file",         required_argument, NULL, 'P' },
   { "pidfile",          required_argument, NULL, 'P' },
+  { "print-uri",        no_argument,       NULL, PRINT_URI },
+  { "print-url",        no_argument,       NULL, PRINT_URI },
   { "port",             required_argument, NULL, 'p' },
   { "read-only",        no_argument,       NULL, 'r' },
   { "readonly",         no_argument,       NULL, 'r' },
   { "run",              required_argument, NULL, RUN_OPTION },
   { "selinux-label",    required_argument, NULL, SELINUX_LABEL_OPTION },
   { "short-options",    no_argument,       NULL, SHORT_OPTIONS_OPTION },
+  { "show-uri",         no_argument,       NULL, PRINT_URI },
+  { "show-url",         no_argument,       NULL, PRINT_URI },
   { "single",           no_argument,       NULL, 's' },
   { "stdin",            no_argument,       NULL, 's' },
   { "swap",             no_argument,       NULL, SWAP_OPTION },
@@ -113,7 +122,29 @@ static const struct option long_options[] = {
 static inline bool
 is_short_name (const char *filename)
 {
-  return strchr (filename, '.') == NULL && strchr (filename, '/') == NULL;
+  const size_t n = strlen (filename);
+  size_t i;
+
+  for (i = 0; i < n; ++i) {
+    switch (filename[i]) {
+    case '/': case '\\':        /* directory separators */
+    case ':': case ';':         /* path separators */
+    case ' ':
+    case '.':
+    case ',':
+    case '=':                   /* nbdkit parameter separator */
+      return false;
+
+      /* non-printable ASCII */
+    case 127:
+      return false;
+    default:
+      if ((unsigned)filename[i] <= 31)
+        return false;
+    }
+  }
+
+  return strstr (filename, DIR_SEPARATOR_STR) == NULL;
 }
 
 #endif /* NBDKIT_OPTIONS_H */
