@@ -4,8 +4,9 @@
 "       [--filter=FILTER ...] [-f|--foreground]\n"
 "       [-g|--group GROUP] [-i|--ipaddr IPADDR]\n"
 "       [--log=stderr|syslog|null] [--mask-handshake=MASK]\n"
-"       [-n|--newstyle] [--no-sr] [-o|--oldstyle]\n"
-"       [-P|--pidfile PIDFILE] [-p|--port PORT]\n"
+"       [-n|--newstyle] [--no-mc|--no-meta-contexts]\n"
+"       [--no-sr|--no-structured-replies] [-o|--oldstyle]\n"
+"       [-P|--pidfile PIDFILE] [-p|--port PORT] [--print-uri]\n"
 "       [-r|--readonly] [--run 'COMMAND ARGS ...']\n"
 "       [--selinux-label=LABEL] [-s|--single] [--swap]\n"
 "       [-t|--threads THREADS] [--tls=off|on|require]\n"
