@@ -56,9 +56,14 @@ for i in $(nbdkit --long-options | $nocr); do
         --no-fork) ;;           # alias of -f
         --ip-addr) ;;           # alias of -i, --ipaddr
         --new-style) ;;         # alias of -n, --newstyle
+        --no-mc) ;;             # alias of --no-meta-contexts
+        --no-sr) ;;             # alias of --no-structured-replies
         --old-style) ;;         # alias of -o, --oldstyle
         --pid-file) ;;          # alias of -P, --pidfile
+        --print-url) ;;         # alias of --print-uri
         --read-only) ;;         # alias of -r, --readonly
+        --show-uri) ;;          # alias of --print-uri
+        --show-url) ;;          # alias of --print-uri
         --stdin) ;;             # alias of -s, --single
 
         # Anything else is tested.
