@@ -1,6 +1,6 @@
 #!/usr/bin/env bash
 # nbdkit
-# Copyright (C) 2016 Red Hat Inc.
+# Copyright Red Hat
 #
 # Redistribution and use in source and binary forms, with or without
 # modification, are permitted provided that the following conditions are
@@ -40,22 +40,3 @@ if [[ ! ( "$output" =~ ^nbdkit\ 1\. ) ]]; then
     echo "$output"
     exit 1
 fi
-
-# Run nbdkit plugin --version for each plugin.
-# However some of these tests are expected to fail.
-test ()
-{
-    vg=; [ "$NBDKIT_VALGRIND" = "1" ] && vg="-valgrind"
-    case "$1$vg" in
-        vddk | vddk-valgrind)
-            echo "$0: skipping $1$vg because VDDK cannot run without special environment variables"
-            ;;
-        python-valgrind | ruby-valgrind | tcl-valgrind)
-            echo "$0: skipping $1$vg because this language doesn't support valgrind"
-            ;;
-        *)
-            nbdkit $1 --version
-            ;;
-    esac
-}
-foreach_plugin test
